local _G = _G
module(...)
scores = {
-- every state of element is sum with enothers
	name = "Scores",
	tag = "synergy_group",
	order = 6,
	description = "State depends on number of points scored by subelements (OK = 0, WARNING = 1 and CRITICAL = 2)",
	hint = "Group score",
	rule = function(items, wr_points, cr_points)
		local sum = 0
		local n = 0
		local state_map = { "OK", "WARNING", "CRITICAL" }
		local res_st = 2
		local tmpl_msg = "Group scored up %d points - meeting %s"
		for i,value in _G.ipairs(items) do
			sum = sum + value.status
			n = n + 1
		end
		if n == 0 then return {{ status = 3, msg = "No state, default state UNKNOWN" }} end
		if sum < wr_points then res_st = 0
		elseif sum < cr_points then res_st = 1
		end
		return {{ status = res_st, msg = _G.string.format(tmpl_msg, sum, state_map[res_st+1]) }}
	end,
	params = {
		{
			validation = {
				required = true,
				number = true,
				min = { 0 },
				lt = { true, "cr_points", "CRITICAL points" }
			},
			name = "wr_points",
			label = "WARNING points",
			type = "number",
			hint = "Number of points for WARNING state"
		},
		{
			validation = {
				required = true,
				number = true,
				min = { 0 },
				gt = { true, "wr_points", "WARNING points" }
			},
			name = "cr_points",
			label = "CRITICAL points",
			type = "number",
			hint = "Number of points for CRITICAL state"
		}
	}
}
